Learn R Programming

domainsignatures (version 1.32.0)

getKEGGdata: Fetch KEGG annotations and InterPro domains

Description

Get all available KEGG annotations and InterPro domains for a set of entrezgene identifiers from the KEGG annotation package and from the ensembl biomaRt.

Usage

getKEGGdata(universe=NULL, pathways=NULL, ensemblMart="hsapiens_gene_ensembl")

Arguments

universe
Character vector of entrezgene identifiers. This is the global universe of genes to test against.
pathways
Optional character vector of KEGG pathway identifiers. This can be used in order to test for over-representation of only a subset of all the available KEGG pathways.
ensemblMart
Character giving the type of Biomart to use. Defaults to Human Ensembl.

Value

An object of class ipDataSource.

Details

This function is a wrapper around the KEGG annotation package and a customized query of the ensembl biomaRt database. For the gene identifiers in universe and all or a selection of KEGG pathways it will fetch the necessary information and create an object of class ipDataSource which can later be used as input to gseDomain

See Also

gseDomain

Examples

Run this code
if(interactive())
getKEGGdata()

Run the code above in your browser using DataLab