gseDomain: Geneset enrichment based on InterPro domain signatures
Description
Compute the similarity to pathways specified trough dataSource
for a set of entrezgene identifiers.
Usage
gseDomain(dataSource, geneset, n=10000, verbose=TRUE, samples=FALSE)
Arguments
dataSource
Object of class ipDataSource containing
pathway and InterPro domain mappings
geneset
Character vector of entrezgene identifiers
n
Number of subsampling iterations
verbose
Toggle progress report
samples
Logical indicating whether to return the similarity
measures for all the resamples.
Value
A list with items- similarity
- Named vector of similarity measures for each
pathway
- pvalue
- The p-values of similarity to each pathway. A named
vector.
and optional item (if samples=TRUE)- dist
- A named list containing similarity measures for all the
resamples
Details
Use this function to compute p-values for similarity of the domain
signature of a gene set to all signatures of the pathways defined in
dataSource. You should have created dataSource using
either function dataSource or getKEGGdata.
Examples
Run this code## see Vignette of this package for examples how to use this function
Run the code above in your browser using DataLab